# SCUNET
命令行登录SCUNET

# How to use

## 安装
本程序依赖于python，且只在python3 on win10 测试通过，未测试其他环境。
```bash
$ pip3 install scunet
```

## 打开终端

- 登入

```bash
$ scunet 
```

- 注销

```bash
$ scunet logout
```
- 重置账户密码

```bash
$ scunet reset
```

- 查看帮助信息

```bash
$ scunet help
```

# Hint
- 账户信息保存在`~/.scunet.json`
- win10将会使用toast提示命令执行情况，如果不需要该提示框, 重设用户信息的时候选择`n`即可

# Todo
- [x] win10使用toast提醒消息
- [x] 使用pypi进行分发
- [ ] 使用python原生http


# Changelog
- 2018-10-12 02:07:57 1.0.0 正式版释出, 只在win10下完整测试兼容性，mac和linux未完整测试

# More

不接受任何形式的提需求，只接受PR :)





Les1ie

2018-9-19 20:50:22